@@ -308,8 +308,8 @@ def build(branch='', ngBuild='', ngApp='', angularBuild='', angularEnv='', angul
 # Otherwise call without, so suitable for app builds.
         if ngBuild:
             options = ' --configuration=%s ' % angularEnv if angularEnv else ''
-            local('yarn build %s %s' % (options, ngApp))
-            local('cp {package.json,yarn.lock,knexfile.js, requirements.txt} dist/')
+            local('yarn build %s %s' % (ngApp, options))
+            local('cp {package.json,yarn.lock,knexfile.js,requirements.txt} dist/')
             local('cp -R migrations/ dist')
             local('if [ -d "apps/%s/config" ]; then cp -R "apps/%s/config" "dist/apps/%s/"; fi' % (ngApp,ngApp,ngApp))
 
